# -*- coding: utf-8 -*-
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


SHARES = {
    'facebook': {
        'share_url': 'https://www.facebook.com/sharer/sharer.php?u={0}',
        'label': 'Facebook',
        'cssClass': 'fab fa-facebook-f',
    },
    'twitter': {
        'share_url': 'https://twitter.com/intent/tweet?url={0}&text={1}',

        'label': 'Twitter',
        'cssClass': 'fab fa-twitter',
    },
    'google': {
        'share_url': 'https://plus.google.com/share?url={0}',
        'label': 'Google',
        'cssClass': 'fab fa-google-plus-g',
    },
    'linkedin': {
        'share_url': 'http://www.linkedin.com/shareArticle?url={0}&title={1}',
        'label': 'Linkedin',
        'cssClass': 'fab fa-linkedin-in',
    },
    'pinterest': {
        'share_url': 'https://pinterest.com/pin/create/bookmarklet/?media={0}&url={1}&is_video={2}&description={3}',  # noqa
        'label': 'Pinterest',
        'cssClass': 'fab fa-pinterest',
    },
    'pocket': {
        'share_url': 'https://getpocket.com/save?url={0}&title={1}',
        'label': 'Pocket',
        'cssClass': 'fab fa-pocket',
    },
}


@implementer(IVocabularyFactory)
class SocialsVocabulary(object):
    """
    Vocabulary factory
    """

    def __call__(self, context):
        voc_values = [
            SimpleTerm(
                x,
                x,
                SHARES.get(x).get('label')) for x in SHARES]
        return SimpleVocabulary(voc_values)


SocialsVocabularyFactory = SocialsVocabulary()



# -*- coding: utf-8 -*-
from design.plone.theme import logger
from design.plone.theme.controlpanel.interfaces import (
    IDesignPloneThemeSettings,
)  # noqa
from pkg_resources import parse_version
from plone import api
from plone.registry.interfaces import IRegistry
from zope.component import getUtility


DEFAULT_PROFILE = 'profile-design.plone.theme:default'


def import_registry(registry_id, dependencies=False):
    setup_tool = api.portal.get_tool('portal_setup')
    setup_tool.runImportStepFromProfile(
        DEFAULT_PROFILE, registry_id, run_dependencies=dependencies
    )


def import_css_registry(context):
    'Import CSS registry configuration'
    logger.info(
        'Importing CSS registry configuration for ' + 'design.plone.theme'
    )
    import_registry('cssregistry')


def import_js_registry(context):
    'Import js registry configuration'
    logger.info(
        'Importing js registry configuration for ' + 'design.plone.theme'
    )
    import_registry('jsregistry')


def import_actions_registry(context):
    'Import actions registry configuration'
    logger.info(
        'Importing actions registry configuration for ' + 'design.plone.theme'
    )
    import_registry('actions')


def import_types_registry(context):
    'Import types registry configuration'
    logger.info(
        'Importing types registry configuration for ' + 'design.plone.theme'
    )
    import_registry('typeinfo')


def import_viewlets_registry(context):
    'Import viewlets registry configuration'
    logger.info(
        'Importing viewlets registry configuration for ' + 'design.plone.theme'
    )
    import_registry('viewlets')


def import_properties_registry(context):
    'Import properties registry configuration'
    logger.info(
        'Importing properties registry configuration for '
        + 'design.plone.theme'
    )
    import_registry('propertiestool')


def import_records_registry(context):
    'Import records and settings'
    logger.info(
        'Importing records and settings configuration for'
        + 'design.plone.theme'
    )
    import_registry('plone.app.registry')


def clean_follow_us_fields(context):
    remove_fields = [
        'header_facebook_link',
        'header_youtube_link',
        'header_twitter_link',
    ]
    registry = getUtility(IRegistry)
    for field in remove_fields:
        try:
            del registry.records[
                '{0}.{1}'.format(
                    IDesignPloneThemeSettings.__identifier__, field
                )
            ]
        except KeyError:
            # entry not present in registry
            continue
    import_records_registry(context)


def fix_default_header_links(context):
    header_link_label = api.portal.get_registry_record(
        'header_link_label', interface=IDesignPloneThemeSettings
    )
    header_link_url = api.portal.get_registry_record(
        'header_link_url', interface=IDesignPloneThemeSettings
    )
    if not header_link_label:
        api.portal.set_registry_record(
            'header_link_label',
            u'Governo Italiano',
            interface=IDesignPloneThemeSettings,
        )
    if not header_link_url:
        api.portal.set_registry_record(
            'header_link_url',
            'http://www.governo.it',
            interface=IDesignPloneThemeSettings,
        )


def to_1300(context):
    """ """
    plone_version = api.env.plone_version()
    if parse_version(plone_version) >= parse_version('5.1.4'):
        # remove custom js
        registry = getUtility(IRegistry)
        reg_key = 'plone.bundles/plone-logged-in.jscompilation'
        registry[reg_key] = '++plone++static/plone-logged-in-compiled.min.js'



# -*- coding: utf-8 -*-
from ..controlpanel.interfaces import IDesignPloneThemeSettings
from ..vocabularies import SHARES
from plone import api
from plone.api.exc import InvalidParameterError
from plone.app.layout.viewlets import common as base
from plone.app.layout.viewlets.common import SearchBoxViewlet
from plone.app.layout.viewlets.content import DocumentBylineViewlet
from plone.app.multilingual.browser.selector import LanguageSelectorViewlet
from Products.CMFPlone.utils import getSiteLogo
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from urllib2 import quote

import logging


logger = logging.getLogger(__name__)

socialCSSClassDict = {
    'facebook': 'fab fa-facebook-f',
    'twitter': 'fab fa-twitter',
    'instagram': 'fab fa-instagram',
    'telegram': 'fab fa-telegram',
    'youtube': 'fab fa-youtube',
    'linkedin': 'fab fa-linkedin-in',
    'medium': 'fab fa-medium-m',
    'newsletter': 'far fa-newspaper',
    'rss': 'fas fa-rss',
    'google': 'fab fa-google-plus-g',
    'pinterest': 'fab fa-pinterest',
    'flickr': 'fab fa-flickr',
    'pocket': 'fab fa-get-pocket',
}


class CustomDocumentBylineViewlet(DocumentBylineViewlet):

    index = ViewPageTemplateFile('templates/document_by_line.pt')

    def show(self):
        # always show: anonymous need to see some infos
        return True

    def creator(self):
        """ show creator infos only for authenticated users """
        return not self.anonymous and self.context.Creator() or ''


class SocialViewlet(base.ViewletBase):
    def __init__(self, context, request, view, manager):
        super(SocialViewlet, self).__init__(context, request, view, manager)

    def render(self):
        """
        """
        allowed_types = api.portal.get_registry_record(
            'available_types', interface=IDesignPloneThemeSettings)
        if self.context.portal_type in allowed_types:
            return self.index()
        return ''

    def get_socials(self):
        socials = api.portal.get_registry_record(
            'available_socials', interface=IDesignPloneThemeSettings)
        return socials

    def get_css_class(self, social_type):
        cssClass = SHARES[social_type]['cssClass']
        return cssClass or ''

    def get_sharer_url(self, social_type):
        share_url = SHARES[social_type]['share_url']
        title = quote(self.context.title.encode('utf-8'))
        item_url = self.context.absolute_url()
        if social_type == 'linkedin':
            return share_url.format(item_url, title)
        if social_type == 'twitter':
            return share_url.format(item_url, title)
        if social_type == 'pinterest':
            return share_url.format('', item_url, 'false', title)
        if social_type == 'pocket':
            return share_url.format(item_url, title)
        return share_url.format(item_url)


class LogoViewlet(base.ViewletBase):
    index = ViewPageTemplateFile('templates/logo.pt')

    def update(self):

        super(LogoViewlet, self).update()
        self.site_title = api.portal.get_registry_record('plone.site_title', )

        self.navigation_root_title = self.site_title
        self.logo_title = self.site_title
        self.img_src = getSiteLogo()


class HeaderSocialViewlet(base.ViewletBase):
    '"Follow us" viewlet'
    index = ViewPageTemplateFile('templates/header_social_viewlet.pt')

    def get_links_list(self):
        try:
            return api.portal.get_registry_record(
                'follow_us_links', interface=IDesignPloneThemeSettings)
        except InvalidParameterError:
            return []

    def get_social_links(self):
        links = self.get_links_list()
        res = []
        for link in links:
            try:
                social, url = link.split('|')
                cssClass = socialCSSClassDict.get(social.strip(), '')
                res.append({'id': social, 'url': url, 'cssClass': cssClass})
            except ValueError:
                logger.warning(
                    '[HeaderSocialViewlet] - skipped entry "{0}"'
                    ' because is malformed. Check it in control panel.')
                continue
        return res


class SkipLinksViewlet(base.ViewletBase):
    'Skiplinks viewlet'
    index = ViewPageTemplateFile('templates/skip_links_viewlet.pt')


class AgidSearchBoxViewlet(SearchBoxViewlet):
    """ Search viewlet """
    index = ViewPageTemplateFile('templates/searchbox.pt')


class HeaderBannerViewlet(LanguageSelectorViewlet):
    """ Header banner viewlet """

    def get_value_from_registry(self, record):
        try:
            value = api.portal.get_registry_record(
                record, interface=IDesignPloneThemeSettings)
        except KeyError:
            value = u''

        return value

    def get_bool_value_from_registry(self, record):
        try:
            value = api.portal.get_registry_record(
                record, interface=IDesignPloneThemeSettings)
        except KeyError:
            value = False

        return value

    def update(self):
        super(HeaderBannerViewlet, self).update()

        self.header_link_label = self.get_value_from_registry(
            'header_link_label')
        self.header_link_url = self.get_value_from_registry('header_link_url')
        self.header_second_link_label = self.get_value_from_registry(
            'header_second_link_label')
        self.header_second_link_url = self.get_value_from_registry(
            'header_second_link_url')
        self.login_button_visible = self.get_bool_value_from_registry(
            'login_button_visible')

    def showLanguageSelector(self):
        return (self.header_link_label and self.header_link_url) or (
            self.header_second_link_url and self.header_second_link_url
        ) or self.login_button_visible or self.available()

    def getUserInfos(self):
        if api.user.is_anonymous():
            return {}
        user = api.user.get_current()
        return {
            'id': user.getProperty('id'),
            'fullname': user.getProperty('fullname') or user.getProperty('id')
        }
